import sys
import os
from csc_util import *

def deleteTemp(fileName):
    print "Removing temporary file", fileName + ',', "please confirm (Y/N)."
    if raw_input().upper() == 'Y':
        os.remove(fileName)
    print "--> Temporary file removed."

def wadd(weapon, level, energy, ammo, dest):
    """Add a weapon to the player's inventory."""
    print "--> Adding weapon", weapon, 'at level', level, 'with', energy, 'energy and', ammo, "ammo."
    if weapon > 13 or weapon in (0,6,8,11) or weapon < 0:
        print "Invalid weapon ID."
        return
    if level > 3 or level < 1:
        print "Invalid weapon level."
        return
    profile = file(dest,'r+b')
    curoffset = 0x38
    done = False
    while not done:
        if curoffset > 0xC4:
            print "Sorry, no more weapons can be added."
            break
        profile.seek(curoffset)
        curtype = profile.read(1)
        if curtype == '\0':
            done = True
        elif curtype == chr(weapon):
            print "--> Weapon", weapon, "is already present. Its attributes will be updated."
            return
        else:
            curoffset += 20
    profile.seek(curoffset)
    profile.write(numToLittleEndian(weapon,4))
    profile.seek(curoffset+4)
    profile.write(numToLittleEndian(level,4))
    profile.seek(curoffset+8)
    profile.write(numToLittleEndian(energy,4))
    profile.seek(curoffset+12)
    profile.write(numToLittleEndian(ammo,4))
    profile.seek(curoffset+16)
    profile.write(numToLittleEndian(ammo,4))
    profile.close()
    

def wrem(weapon, dest):
    """Remove a weapon from the player's inventory, and shift existing weapons down."""
    profile = file(dest,'r+b')
    curoffset = 0x38
    found = False
    while curoffset <= 0xC4:
        if found:
            profile.seek(curoffset)
            next = profile.read(20)
            profile.seek(curoffset-20)
            profile.write(next)
        else:
            profile.seek(curoffset)
            curtype = profile.read(1)
            if curtype == chr(weapon): found = True
        curoffset += 20
    profile.seek(0xC4)
    profile.write('\0' * 20)
    if not found:
        print "The weapon wasn't found; the profile has not been altered."
    else:
        print "--> Weapon", weapon, "removed."
    profile.close()

def iadd(item, equip, dest):
    """Add an item to the player's inventory."""
    print "--> Adding item", `item` + '.'
    if item > 27:
        print "Invalid item ID."
        return
    profile = file(dest,'r+b')
    curoffset = 0xD8
    done = False
    while not done:
        if curoffset > 0x154:
            print "Sorry, no more items can be added."
            break
        profile.seek(curoffset)
        curtype = profile.read(1)
        if curtype == '\0':
            done = True
        elif curtype == chr(item):
            print "--> Item", item, "is already present. Its equipped status will be updated if applicable."
            return
        else:
            curoffset += 4
    profile.seek(curoffset)
    profile.write(numToLittleEndian(item))
    profile.close()
    # TODO: implement item equipping

def irem(item, dest):
    """Remove an item from the player's inventory, and shift existing items down."""
    print "--> Removing item", `item` + '.'
    profile = file(dest,'r+b')
    curoffset = 0xD8
    found = False
    while curoffset <= 0x154:
        if found:
            profile.seek(curoffset)
            next = profile.read(4)
            profile.seek(curoffset-4)
            profile.write(next)
        else:
            profile.seek(curoffset)
            curtype = profile.read(1)
            if curtype == chr(item): found = True
        curoffset += 4
    profile.seek(0xC4)
    profile.write('\0' * 4)
    if not found:
        print "The item wasn't found; the profile has not been altered."
    else:
        print "--> Item", item, "removed."
    profile.close()

def edit(attrs, dest):
    notImplemented = None
    profile = file(dest, 'r+b')
    def writeAt(what,where):
        profile.seek(where)
        profile.write(what)
    if attrs.has_key('maxhp'):
        writeAt(numToLittleEndian(attrs['maxhp']),0x1C)
    elif attrs.has_key('hp'):
        if attrs['hp'] == 'max':
            profile.seek(0x1C)
            attrs['hp'] = profile.read(4)
        else:
            attrs['hp'] = numToLittleEndian(attrs['hp'])
        writeAt(attrs['hp'],0x20)
    elif attrs.has_key('map'):
        notImplemented
    elif attrs.has_key('song'):
        notImplemented
    elif attrs.has_key('horz'):
        notImplemented
    elif attrs.has_key('vert'):
        notImplemented
    elif attrs.has_key('dir'):
        notImplemented
    elif attrs.has_key('star'):
        notImplemented
    elif attrs.has_key('weapon'):
        notImplemented
    elif attrs.has_key('time'):
        notImplemented
    # TODO: implement these other attributes
    # 008-00B | current map
    # 00C-00F | current song?
    # 010-013 | horizontal pos
    # 014-017 | vertical pos
    # 018-01B | facing direction
    # 01C-01D | max HP
    # 01E-01F | whimsical star
    # 020-021 | Current HP
    # 022-023 | Unused? Possibly alignment filler
    # 024-027 | Current Weapon
    # 028-02B | Unused?
    # 02C-02F | Equipped Items
    # 030-033 | Unused?
    # 034-037 | Time
    # 158-15B | Slot 1 Teleporter Menu
    # 15C-15F | Slot 1 Teleporter Location
    # 160-163 | Slot 2 Teleporter Menu
    # 164-167 | Slot 2 Teleporter Location
    # 168-16B | Slot 3 Teleporter Menu
    # 16C-16F | Slot 3 Teleporter Location
    # 170-173 | Slot 4 Teleporter Menu
    # 174-177 | Slot 4 Teleporter Location
    # 178-17B | Slot 5 Teleporter Menu
    # 17C-17F | Slot 5 Teleporter Location
    # 180-183 | Slot 6 Teleporter Menu
    # 184-187 | Slot 6 Teleporter Location
    # 188-18B | Slot 7 Teleporter Menu
    # 18C-18F | Slot 7 Teleporter Location
    # 190-193 | Slot 8 Teleporter Menu
    # 194-197 | Slot 8 Teleporter Location